@@ -6,7 +6,7 @@ use Dist::Joseki;
 use Dist::Joseki::Find;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 use base 'Dist::Joseki::Cmd::Multiplexable';
@@ -90,8 +90,8 @@ functions:
 
 The superclass L<Dist::Joseki::Base> defines these methods and functions:
 
-    assert_is_dist_base_dir(), bool_prompt(), print_header(),
-    read_from_cmd(), safe_system()
+    assert_is_dist_base_dir(), print_header(), read_from_cmd(),
+    safe_system()
 
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
@@ -132,7 +132,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.09 of L<Dist::Joseki::Cmd::Command::clean>.
+This document describes version 0.10 of L<Dist::Joseki::Cmd::Command::clean>.
 
 =head1 BUGS AND LIMITATIONS
 
