@@ -11,7 +11,7 @@ use Parse::CPAN::Packages;
 use Perl::Version;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 use base 'Dist::Joseki::Cmd::Multiplexable';
@@ -200,8 +200,8 @@ functions:
 
 The superclass L<Dist::Joseki::Base> defines these methods and functions:
 
-    assert_is_dist_base_dir(), bool_prompt(), print_header(),
-    read_from_cmd(), safe_system()
+    assert_is_dist_base_dir(), print_header(), read_from_cmd(),
+    safe_system()
 
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
@@ -242,7 +242,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.09 of L<Dist::Joseki::Cmd::Command::depends>.
+This document describes version 0.10 of L<Dist::Joseki::Cmd::Command::depends>.
 
 =head1 BUGS AND LIMITATIONS
 
