@@ -5,7 +5,7 @@ use warnings;
 use Dist::Joseki::Find;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 use base qw(Dist::Joseki::Cmd::Command);
@@ -93,8 +93,8 @@ functions:
 
 The superclass L<Dist::Joseki::Base> defines these methods and functions:
 
-    assert_is_dist_base_dir(), bool_prompt(), print_header(),
-    read_from_cmd(), safe_system()
+    assert_is_dist_base_dir(), print_header(), read_from_cmd(),
+    safe_system()
 
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
@@ -135,7 +135,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.09 of L<Dist::Joseki::Cmd::Multiplexable>.
+This document describes version 0.10 of L<Dist::Joseki::Cmd::Multiplexable>.
 
 =head1 BUGS AND LIMITATIONS
 
