@@ -5,7 +5,7 @@ use warnings;
 use Module::Changes;
 
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 use base qw(Dist::Joseki::Base);
@@ -37,8 +37,8 @@ Dist::Joseki::SVK::Status inherits from L<Dist::Joseki::Base>.
 
 The superclass L<Dist::Joseki::Base> defines these methods and functions:
 
-    new(), assert_is_dist_base_dir(), bool_prompt(), print_header(),
-    read_from_cmd(), safe_system()
+    new(), assert_is_dist_base_dir(), print_header(), read_from_cmd(),
+    safe_system()
 
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
@@ -725,7 +725,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.09 of L<Dist::Joseki::SVK::Status>.
+This document describes version 0.10 of L<Dist::Joseki::SVK::Status>.
 
 =head1 BUGS AND LIMITATIONS
 
